+++
title = "Title with _lots and _lots _ _ of under_scores__"
tags = ["title"]
draft = false
+++

-   All underscore characters meant for Org `_underline_` markup are
    removed.
-   The rest of the underscore characters are retained.
